from enum import Enum
from select import POLLIN, POLLPRI, POLLOUT, POLLERR, POLLHUP, POLLRDHUP, POLLNVAL


class HttpMethods(Enum):
    GET = "GET"
    POST = "POST"
    PUT = "PUT"
    PATCH = "PATCH"
    DELETE = "DELETE"
    HEAD = "HEAD"
    OPTIONS = "OPTIONS"
    TRACE = "TRACE"


class PollMaskGroups:
    READ_SIMPLE = [POLLIN]

    READ_COMPLEX = [POLLIN | POLLPRI]

    READ_WRITES = [POLLIN | POLLOUT, POLLIN | POLLPRI | POLLOUT]

    ALL_READS = READ_SIMPLE + READ_COMPLEX + READ_WRITES

    WRITE_SIMPLE = [POLLOUT]

    READ_WRITE_SIMPLE = READ_SIMPLE + WRITE_SIMPLE

    ERROR = [POLLERR]

    HANGUPS = [POLLHUP, POLLRDHUP, POLLHUP | POLLRDHUP]

    INVAL = [POLLNVAL]

    BADS = ERROR + HANGUPS + INVAL


# We don't make this a clean read just to keep IO out of the equasion.

default_ssl_cert = """-----BEGIN CERTIFICATE-----
MIIFbTCCA1WgAwIBAgIUd2D4Kqevc1ONY6ZeSyeL9kuLwQEwDQYJKoZIhvcNAQEL
BQAwRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoM
GEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDAgFw0yMDA1MjgxMjE5MzNaGA8yMTIw
MDUwNDEyMTkzM1owRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUx
ITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDCCAiIwDQYJKoZIhvcN
AQEBBQADggIPADCCAgoCggIBAMQ01K/FnYvg2kkMz/cM/546ajKXuCDsiObP4QHS
DDCnYnXZPRaK5e3jqCmg87GzaS1KQyUH5Q9U3dNr/84/wXLBTmDzB5fIM4+mzYmv
fOEDvAzPaNyDXcmIWtyyjKgGu3aB1Ws7EYYoUiM2bLZYG8F3iOohqifa+S5bHYiS
zNmza9ozoAVVByJW2NEFMR9WcjzrgQly91B2L7nLP/ATiSKR30Mr9VqM8fuYP1wL
H8iIf/rAxVarvqaBmR6HaWFeXLoX0SmKA8vhgmMgfXQGsHvvY8CuPs4EGQVFRqb8
ilj0ug8w88x7V0ZE0y5K3pwaovdchByut94m6ddE1fTns7mlLOVXa4ItuWX31ymT
2bTIt3sH8HeSJKAj/vFOvOwkuVWis7v5dTTBoHODncp0bVW8VqKgX0t2CAc3CY3A
3fHlmUkFndCTlxHNhU2DC0PJmZhLiwWuwUURphmPYeY5TEfopDNQU6sDUPEiLNIr
/OLeqHsjJIgDv1AJZiWDBtOPLgNKzGUJaXp3+CKaS9SxxSL3PVQ63imJw9tFUUeg
fFrfom7uhAJVb08wYMMaT4idGOTnbbrNV91o+Hu2w5ejhBweCwzoCgJ4B8U412q4
I4Ou8UWP+xbCvKMRcA/n22oLq7qzUbwcNWVTJuBzhZb1xlJcdYIRonmSHhD1Q59Z
IkELAgMBAAGjUzBRMB0GA1UdDgQWBBQz3njhMjMloVMViR8oJL6+Enb3aTAfBgNV
HSMEGDAWgBQz3njhMjMloVMViR8oJL6+Enb3aTAPBgNVHRMBAf8EBTADAQH/MA0G
CSqGSIb3DQEBCwUAA4ICAQBxdfpSChyS96kdYc013GIQiBJApK7JhnHFuIXFhBst
Fx61lU73PkIl8TcA4sYRkmcbReUMhRFUDYgzqvmewZnBWeVQbYuBEZVfN1T7M4eJ
6RHwUelTo81EXkx/DDKFVkObv/QLhJD3MAQBmXL2l+2yezSdVInXYpM31d2Fb27G
g0gSJXv4PpceFRVlVIp0xu+TMKIvZ6K+PX+TSfucVh+zPzoTLuIQG4AIuJWdeFNA
36915fyMt5mLdLusHnchjn5dsNFC/zXYt8s1u+5qLDVJbisblIZEizst/wx+s1pT
cEITjlQ+G8jGlvvTpiszcwPYrnnXq08QgUwTCwEqyTpPtMMLcmmK8fBp/cruxVAW
pxVLgJjjxVz1Q1gWOG7Lw54FIJrsV+fyGsV4IsUMC7wbKyehIWwzkUO0p6N2y5Fp
FHXvYsbXiuHymzhqCLenO/Me9F1uk5b8JrgEs8SuUtDVdmF7Bias9U21Y83IjI3S
EtYYKcTdoHPRoa1X6bWJzoskNdYbzJ2Y9XcC3+NkwIBn06aGxeoQ9MJalP35+whw
PwBclZjnVsujJITHFC7arqwfJZP9MON4iT2cvMkW1sHWHsIYnpg9LiM6hVelKpIS
ILHnknvF0Mk+DmTcTnLULohHWq/D8w1G5drt8DA+/KsaYXcLIzbvFymFz1RIFbrW
BQ==
-----END CERTIFICATE-----
"""
